Basis functions
===============

All of your basis functions inherit from the base class BasisFunction.

.. autoclass:: splinebox.basis_functions.BasisFunction
   :members:
   :undoc-members:


.. toctree::
   :maxdepth: 1
   :hidden:

   b1.rst
   b2.rst
   b3.rst
   exponential.rst
   catmullrom.rst
   cubichermite.rst
   exponentialhermite.rst
